@@ -16,18 +16,16 @@
 
 FirstRunDialog::FirstRunDialog(MainWindow *mainWindow)
     : QDialog(mainWindow)
+    , m_mainWindow(mainWindow)
 {
-    m_mainWindow = mainWindow;
-
     setWindowTitle(xi18nc("@title:window", "First Run"));
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
-    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &FirstRunDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &FirstRunDialog::reject);
 
     QWidget *widget = new QWidget(this);
     mainLayout->addWidget(widget);
