@@ -26,7 +26,7 @@ class SessionStack : public QStackedWidget
 
 public:
     explicit SessionStack(QWidget *parent = nullptr);
-    ~SessionStack();
+    ~SessionStack() override;
 
     void closeActiveTerminal(int sessionId = -1);
 
@@ -128,7 +128,7 @@ Q_SIGNALS:
     void wantsBlurChanged();
 
 protected:
-    virtual void showEvent(QShowEvent *event) override;
+    void showEvent(QShowEvent *event) override;
 
 private Q_SLOTS:
     void handleManualTerminalActivation(Terminal *);
@@ -142,7 +142,7 @@ private:
     };
     bool queryClose(int sessionId, QueryCloseType type);
 
-    VisualEventOverlay *m_visualEventOverlay;
+    VisualEventOverlay *m_visualEventOverlay = nullptr;
 
     int m_activeSessionId;
 
